// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " K");
    logComment("  available: " + spaceAvailable + " K");
    return(false);
  }

  return(true);
}

// this function deletes a file if it exists
function deleteThisFile(dirKey, file)
{
  var fFileToDelete;

  fFileToDelete = getFolder(dirKey, file);
  logComment("File to delete: " + fFileToDelete);
  if(File.isFile(fFileToDelete))
  {
    File.remove(fFileToDelete);
    return(true);
  }
  else
    return(false);
}

// this function deletes a folder if it exists
function deleteThisFolder(dirKey, folder, recursiveDelete)
{
  var fToDelete;

  if(typeof recursiveDelete == "undefined")
    recursiveDelete = true;

  fToDelete = getFolder(dirKey, folder);
  logComment("folder to delete: " + fToDelete);
  if(File.isDirectory(fToDelete))
  {
    File.dirRemove(fToDelete, recursiveDelete);
    return(true);
  }
  else
    return(false);
}

// OS type detection
// which platform?
function getPlatform()
{
  var platformStr;
  var platformNode;

  if('platform' in Install)
  {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else if (!platformStr.search(/^OS\/2/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else
  {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}

// main
var srDest;
var err;
var fProgram;
var platformNode;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end
// end - OS type detection

// ----LOCALIZATION NOTE: translate only these ------
var prettyName = "Traditional Chinese (zh-TW) Langauge Pack";
var langcode = "zh";
var regionCode  = "TW";
// --- END CHANGABLE STUFF ---

var chromeNode = langcode + "-" + regionCode;
var regionName  = regionCode + ".jar";
var regionLocale= "locale/" + regionCode + "/";
var regName    = "locales/mozilla/" + chromeNode;
var chromeName = chromeNode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName = "locale/" + chromeNode + "/";

var OptionalName = langcode + "-optional" + ".jar";

srDest = 3000;
err    = initInstall(prettyName, regName, "1.7.0.2004061609"); 
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

// searchplugins directory detection
if (platformNode == 'mac') {
  fSearchPlugins = getFolder("Program", "Search Plugins");
}
else {
  fSearchPlugins = getFolder("Program", "searchplugins");
}
logComment("fSearchPlugins: " + fSearchPlugins);
if(verifyDiskSpace(fProgram, srDest))
{
  // install search plugins first
  err = addDirectory("", "searchplugins", fSearchPlugins, "");
  logComment("addDirectory() searchplugins returned: " + err);
  resetError();

  var chromeType = LOCALE;
  var tellRestart = 0;
  if (platformNode == 'unix') {
    // DELAYED_CHROME is still needed on many unix systems for bug 109044; this needs a Mozilla restart!
    logComment("detected a unix system: using DELAYED_CHROME for registerChrome because of bug 109044");
    chromeType |= DELAYED_CHROME;
    tellRestart = 1;
  }
  err = addDirectory("",
                     "bin",     // dir name in jar to extract 
                     fProgram,  // Where to put this file (Returned from GetFolder) 
                     "");       // Force Flag 
  logComment("addDirectory() returned: " + err);

  if (err != SUCCESS)
  {
    logComment("addDirectory() to " + fProgram + "failed!");
    if (platformNode != 'unix') {
      // couldn't install globally, try installing to the profile
      // does not work with DELAYED_CHROME !!! (see comment above - bug 109044)
      resetError();
      chromeType |= PROFILE_CHROME;
      fProgram = getFolder("Profile");
      logComment("try installing to the user profile:" + fProgram);
      err = addDirectory("","bin/chrome",fProgram,"chrome");
    }
    else {
      logComment("can't use user profile due to bug 109044");
      alert ("Due to Mozilla bug #109044, you can only install by root on UNIX.");
    }
    /*  Official version
    // couldn't install globally, try installing to the profile
    resetError();
    chromeType |= PROFILE_CHROME;
    fProgram = getFolder("Profile");
    logComment("try installing to the user profile:" + fProgram);
    err = addDirectory("","bin",fProgram,"");
    */
  }
 
  setPackageFolder(fProgram);
 
  // check return value: 0 is SUCCESS, 999 is REBOOT_NEEDED
  //if (err == SUCCESS)
  if ((err == 0) || (err == 999))
  {
    var tellReboot = 0;
    if (err == 999) {
      tellReboot = 1;
      resetError();
    }
    // register chrome
    var cf = getFolder(fProgram, "chrome/"+chromeName);
    var pf = getFolder(fProgram, "chrome/"+platformName);

    var rf = getFolder(fProgram, "chrome/"+regionName);
    var optionalf = getFolder(fProgram, "chrome/"+OptionalName);

    registerChrome(chromeType, cf, localeName + "global/");
    registerChrome(chromeType, cf, localeName + "communicator/");

    registerChrome(chromeType, cf, localeName + "messenger/");
    registerChrome(chromeType, cf, localeName + "messenger-smime/");
    registerChrome(chromeType, cf, localeName + "messenger-mdn/");

    registerChrome(chromeType, cf, localeName + "editor/");
    registerChrome(chromeType, cf, localeName + "navigator/");
    registerChrome(chromeType, cf, localeName + "necko/");
    registerChrome(chromeType, cf, localeName + "mozldap/");
    registerChrome(chromeType, cf, localeName + "autoconfig/");
    registerChrome(chromeType, cf, localeName + "cookie/");
    registerChrome(chromeType, cf, localeName + "wallet/");
    registerChrome(chromeType, cf, localeName + "content-packs/");
    registerChrome(chromeType, cf, localeName + "help/");
    registerChrome(chromeType, cf, localeName + "pippki/");
    registerChrome(chromeType, cf, localeName + "pipnss/");
    registerChrome(chromeType, cf, localeName + "p3p/");

    registerChrome(chromeType, pf, localeName + "global-platform/");
    registerChrome(chromeType, pf, localeName + "communicator-platform/");
    registerChrome(chromeType, pf, localeName + "navigator-platform/");
    // mesenger-mapi package exists only on windows.
    // Register this package only for windows.
    if (platformNode == "win")
      registerChrome(chromeType, pf, localeName + "messenger-mapi/");

    registerChrome(chromeType, rf, regionLocale + "global-region/");
    registerChrome(chromeType, rf, regionLocale + "communicator-region/");
    registerChrome(chromeType, rf, regionLocale + "editor-region/");
    registerChrome(chromeType, rf, regionLocale + "messenger-region/");
    registerChrome(chromeType, rf, regionLocale + "navigator-region/");

    // Piaip: Register Chatzilla, Venkman, Inspector
    registerChrome(chromeType, optionalf, localeName+"chatzilla/");
    registerChrome(chromeType, optionalf, localeName+"venkman/");
    registerChrome(chromeType, optionalf, localeName+"inspector/");

    err = performInstall(); 
    logComment("performInstall() returned: " + err);
//    alert("Installed Complete. Result is: " + err);
    if (err == 999) {
      tellReboot = 1;
      resetError(); err = 0;
    }
    if (err == 0) {
      if (tellReboot == 1) {
        alert("Installation finished. You need to REBOOT your system before you are able to select to use this locale via Edit > Preferences (Category: Appearance > Languages/Content).");
        logComment("REBOOT_NEEDED (999): warning user that he needs to reboot his system.");
      }
      else {
        if (tellRestart == 1) {
          alert("Installation finished. After a BROWSER RESTART, you should be able to select to use this locale via Edit > Preferences (Category: Appearance > Languages/Content).");
          logComment("we were using DELAYED_CHROME: warning user that he needs to restart Mozilla.");
        }
        else  {
          alert("Installation finished. You should be able to select to use this locale via Edit > Preferences (Category: Appearance > Languages/Content).");
        }
      }
    }
    else {
      alert("Installation failed. Error code was " + err);
    }
  }
  else
  {
    cancelInstall(err);
    logComment("cancelInstall due to error: " + err);
    if ((err == -202) || (err == -215)) {
      // -202 is ACCESS_DENIED, -215 is READ_ONLY
      alert("Installation canceled with error " + err +". It seems you have no write permission to the Mozilla 'chrome' directory. Please install as root / system administrator.");
      if (err == -202) {
        logComment("ACCESS_DENIED (-202): warning user that he probably has no write access to chrome.");
      }
      else {
        logComment("READ_ONLY (-215): warning user that he probably has no write access to chrome.");
      }
    }
    else {
      alert("Installation canceled. Error code was " + err);
    }
  }
}
else
  cancelInstall(INSUFFICIENT_DISK_SPACE);

// end main
